linkml.reporting package — linkml documentation

# linkml.reporting package

## Submodules

## linkml.reporting.model module

class linkml.reporting.model.CheckResult(*args, _if_missing: Optional[Callable[[jsonasobj2._jsonobj.JsonObj, str], Tuple[bool, Any]]] = None, **kwargs)

  Bases: `linkml_runtime.utils.yamlutils.YAMLRoot`

  An individual check

  class_class_curie: ClassVar[str] = 'reporting:CheckResult'
  class_class_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportCheckResult')
  class_model_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportCheckResult')
  class_name: ClassVar[str] = 'check_result'
  info: Optional[str] = None
  instantiates: Optional[Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier]] = None
  object: Optional[Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier]] = None
  object_str: Optional[str] = None
  predicate: Optional[Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier]] = None
  source: Optional[Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier]] = None
  subject: Optional[Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier]] = None
  type: Optional[Union[str, linkml_runtime.utils.metamodelcore.URIorCURIE]] = None

class linkml.reporting.model.Problem(*args, _if_missing: Optional[Callable[[jsonasobj2._jsonobj.JsonObj, str], Tuple[bool, Any]]] = None, **kwargs)

  Bases: `linkml.reporting.model.CheckResult`

  class_class_curie: ClassVar[str] = 'reporting:Problem'
  class_class_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportProblem')
  class_model_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportProblem')
  class_name: ClassVar[str] = 'problem'

class linkml.reporting.model.ProblemSlotInapplicable(*args, _if_missing: Optional[Callable[[jsonasobj2._jsonobj.JsonObj, str], Tuple[bool, Any]]] = None, **kwargs)

  Bases: `linkml.reporting.model.Problem`

  A problem in which a slot is used in an instance of a class where the slot is not applicable for that class

  class_class_curie: ClassVar[str] = 'reporting:ProblemSlotInapplicable'
  class_class_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportProblemSlotInapplicable')
  class_model_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportProblemSlotInapplicable')
  class_name: ClassVar[str] = 'problem_slot_inapplicable'

class linkml.reporting.model.ProblemSlotMissing(*args, _if_missing: Optional[Callable[[jsonasobj2._jsonobj.JsonObj, str], Tuple[bool, Any]]] = None, **kwargs)

  Bases: `linkml.reporting.model.Problem`

  A problem in which an instance of a class has a required slot which is not filled in

  class_class_curie: ClassVar[str] = 'reporting:ProblemSlotMissing'
  class_class_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportProblemSlotMissing')
  class_model_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportProblemSlotMissing')
  class_name: ClassVar[str] = 'problem_slot_missing'

class linkml.reporting.model.ProblemSlotUndeclared(*args, _if_missing: Optional[Callable[[jsonasobj2._jsonobj.JsonObj, str], Tuple[bool, Any]]] = None, **kwargs)

  Bases: `linkml.reporting.model.Problem`

  A problem in which an undeclared slot is used

  class_class_curie: ClassVar[str] = 'reporting:ProblemSlotUndeclared'
  class_class_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportProblemSlotUndeclared')
  class_model_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportProblemSlotUndeclared')
  class_name: ClassVar[str] = 'problem_slot_undeclared'

class linkml.reporting.model.Report(*args, _if_missing: Optional[Callable[[jsonasobj2._jsonobj.JsonObj, str], Tuple[bool, Any]]] = None, **kwargs)

  Bases: `linkml_runtime.utils.yamlutils.YAMLRoot`

  A report object

  class_class_curie: ClassVar[str] = 'reporting:Report'
  class_class_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportReport')
  class_model_uri: ClassVar[rdflib.term.URIRef] = rdflib.term.URIRef('https://w3id.org/linkml/reportReport')
  class_name: ClassVar[str] = 'report'
  results: Optional[Union[dict, linkml.reporting.model.CheckResult, List[Union[dict, linkml.reporting.model.CheckResult]]]]

class linkml.reporting.model.SeverityOptions(*args, _if_missing: Optional[Callable[[jsonasobj2._jsonobj.JsonObj, str], Tuple[bool, Any]]] = None, **kwargs)

  Bases: `linkml_runtime.utils.enumerations.EnumDefinitionImpl`

  ERROR = PermissibleValue(text='ERROR', description=None, meaning=None, is_a=None, mixins=[], extensions={}, annotations={}, alt_descriptions={}, title=None, deprecated=None, todos=[], notes=[], comments=[], examples=[], in_subset=[], from_schema=None, imported_from=None, see_also=[], deprecated_element_has_exact_replacement=None, deprecated_element_has_possible_replacement=None)
  FATAL = PermissibleValue(text='FATAL', description=None, meaning=None, is_a=None, mixins=[], extensions={}, annotations={}, alt_descriptions={}, title=None, deprecated=None, todos=[], notes=[], comments=[], examples=[], in_subset=[], from_schema=None, imported_from=None, see_also=[], deprecated_element_has_exact_replacement=None, deprecated_element_has_possible_replacement=None)
  INFO = PermissibleValue(text='INFO', description=None, meaning=None, is_a=None, mixins=[], extensions={}, annotations={}, alt_descriptions={}, title=None, deprecated=None, todos=[], notes=[], comments=[], examples=[], in_subset=[], from_schema=None, imported_from=None, see_also=[], deprecated_element_has_exact_replacement=None, deprecated_element_has_possible_replacement=None)
  WARNING = PermissibleValue(text='WARNING', description=None, meaning=None, is_a=None, mixins=[], extensions={}, annotations={}, alt_descriptions={}, title=None, deprecated=None, todos=[], notes=[], comments=[], examples=[], in_subset=[], from_schema=None, imported_from=None, see_also=[], deprecated_element_has_exact_replacement=None, deprecated_element_has_possible_replacement=None)

class linkml.reporting.model.slots

  Bases: `object`

  info = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reportinfo'), name='info', curie='reporting:info', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reportinfo'), domain=None, range=typing.Optional[str], mappings=None, pattern=None)
  instantiates = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reportinstantiates'), name='instantiates', curie='reporting:instantiates', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reportinstantiates'), domain=None, range=typing.Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier, NoneType], mappings=None, pattern=None)
  object = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reportobject'), name='object', curie='reporting:object', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reportobject'), domain=None, range=typing.Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier, NoneType], mappings=None, pattern=None)
  object_str = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reportobject_str'), name='object_str', curie='reporting:object_str', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reportobject_str'), domain=None, range=typing.Optional[str], mappings=None, pattern=None)
  predicate = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reportpredicate'), name='predicate', curie='reporting:predicate', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reportpredicate'), domain=None, range=typing.Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier, NoneType], mappings=None, pattern=None)
  report__results = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reportresults'), name='report__results', curie='reporting:results', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reportreport__results'), domain=None, range=typing.Union[dict, linkml.reporting.model.CheckResult, typing.List[typing.Union[dict, linkml.reporting.model.CheckResult]], NoneType], mappings=None, pattern=None)
  severity = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reportseverity'), name='severity', curie='reporting:severity', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reportseverity'), domain=None, range=typing.Union[str, ForwardRef('SeverityOptions'), NoneType], mappings=None, pattern=None)
  source = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reportsource'), name='source', curie='reporting:source', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reportsource'), domain=None, range=typing.Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier, NoneType], mappings=None, pattern=None)
  subject = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reportsubject'), name='subject', curie='reporting:subject', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reportsubject'), domain=None, range=typing.Union[str, linkml_runtime.utils.metamodelcore.NodeIdentifier, NoneType], mappings=None, pattern=None)
  type = Slot(uri=rdflib.term.URIRef('https://w3id.org/linkml/reporttype'), name='type', curie='reporting:type', model_uri=rdflib.term.URIRef('https://w3id.org/linkml/reporttype'), domain=None, range=typing.Union[str, linkml_runtime.utils.metamodelcore.URIorCURIE, NoneType], mappings=None, pattern=None)

## Module contents